export interface KVProviderOptions {
    expirationTtl: number;
}
export interface KVProvider {
    get: (key: string) => Promise<string>;
    put: (key: string, data: string, options: KVProviderOptions) => Promise<void>;
    delete: (key: string) => Promise<void>;
}
export declare namespace BaseProvider {
    interface JWTOptions {
        secret: string;
        phone: string;
        claims: Record<string, string | number>;
    }
    interface VerifyOptions {
        options: {
            kvProvider: KVProvider;
            phone: string;
            otp: string;
            secret: string;
            claims: Record<string, string>;
        };
    }
    interface SendOptions {
        options: {
            region: string;
            otpLength?: number;
            message?: string;
            phone: string;
            kvProvider: KVProvider;
            expirationTtl?: number;
            accountSid: string;
            authToken: string;
            from?: string;
        };
    }
    interface TokensFromCodeOptions {
        clientId: string;
        clientSecret: string;
        redirectUrl?: string;
        isLogEnabled?: boolean;
        userAgent?: string;
    }
    interface ApiError {
        error: string;
        error_description: string;
    }
    interface CallbackOptions {
        options: TokensFromCodeOptions;
        request: Request;
    }
    interface RedirectOptions {
        options: {
            clientId: string;
            redirectTo?: string;
            scope?: string[];
            responseType?: string;
            showDialog?: boolean;
            allowSignup?: boolean;
            state?: string;
            responseMode?: "query" | "fragment" | "form_post";
        };
    }
}
export interface OAuthTokens {
    access_token: string;
    token_type: string;
    scope: string;
    expires_in: number;
    refresh_token: string;
}
